@@ -89,6 +89,7 @@ class Engine:
                                          march_explicit_flag_set):
         PREFIX_NO = '-mno-'
         PREFIX_YES = '-m'
+        PREFIX_MTUNE = '-mtune='
 
         explicit_more_flag_set = march_explicit_flag_set - march_native_flag_set
         for flag in explicit_more_flag_set:
@@ -97,7 +98,8 @@ class Engine:
                       flag, file=sys.stderr)
                 continue
 
-            if not flag.startswith(PREFIX_NO) and flag.startswith(PREFIX_YES):
+            if not flag.startswith(PREFIX_NO) and flag.startswith(PREFIX_YES) \
+                    and not flag.startswith(PREFIX_MTUNE):
                 # march=<explicit> enabled something (too much) that march=native disabled
                 opposite_flag = PREFIX_NO + flag[len(PREFIX_YES):]
                 target_set.add(opposite_flag)
