@@ -4,6 +4,7 @@
 import os
 import re
 import subprocess
+import sys
 from typing import List
 
 from .environment import enforce_c_locale
@@ -13,6 +14,11 @@ from .environment import enforce_c_locale
 # "  -m64                                  [enabled]"
 _enabled_line_pattern = re.compile(r'^\s+(?P<flag>-[^ ]+)\s+\[enabled\]$')
 
+# Example lines:
+# "  -mavx                                 [disabled]"
+# "  -mno-align-stringops        \t\t[disabled]"
+_disabled_m_line_pattern = re.compile(r'^\s+(?P<flag>-m[^ ]+)\s+\[disabled\]$')
+
 # Example lines:
 # "  -mgen-cell-microcode        \t\t[ignored]"
 _ignore_marked_line_pattern = re.compile(r'^\s+(?P<flag>-[^ ]+)\s+\[ignored\]$')
@@ -72,11 +78,15 @@ def get_flags_implied_by_march(arch: str, gcc=None, debug=True) -> List[str]:
     stderr = None if debug else subprocess.DEVNULL
     enforce_c_locale(env)
     try:
-        gcc_output = subprocess.check_output(base_argv + [f'-march={arch}'],
-                                             env=env, stderr=stderr).decode('UTF-8')
+        cmd = base_argv + [f'-march={arch}']
+        if debug:
+            print('# %s' % ' '.join(cmd), file=sys.stderr)
+        gcc_output = subprocess.check_output(cmd, env=env, stderr=stderr).decode('UTF-8')
     except subprocess.CalledProcessError:
-        gcc_output = subprocess.check_output(base_argv + [f'-mcpu={arch}'],
-                                             env=env, stderr=stderr).decode('UTF-8')
+        cmd = base_argv + [f'-mcpu={arch}']
+        if debug:
+            print('# %s' % ' '.join(cmd), file=sys.stderr)
+        gcc_output = subprocess.check_output(cmd, env=env, stderr=stderr).decode('UTF-8')
     return _parse_gcc_output(gcc_output)
 
 
@@ -87,9 +97,6 @@ def _parse_gcc_output(gcc_output: str) -> List[str]:
         if not line.startswith('  -'):
             continue
 
-        if line.endswith('[disabled]'):
-            continue
-
         if line.endswith('[default]'):
             continue
 
@@ -101,6 +108,15 @@ def _parse_gcc_output(gcc_output: str) -> List[str]:
             flags.append(flag)
             continue
 
+        if line.endswith('[disabled]'):
+            flag = _disabled_m_line_pattern.match(line).group('flag')
+            if flag.startswith('-mno-'):
+                # Drop the "no"
+                flags.append('-m' + flag[len('-mno-'):])
+            else:
+                flags.append('-mno-' + flag[len('-m'):])
+            continue
+
         if line.endswith('[ignored]'):
             flag = _ignore_marked_line_pattern.match(line).group('flag')
             flags.append(flag)
@@ -116,7 +132,6 @@ def _parse_gcc_output(gcc_output: str) -> List[str]:
 
         alias_line_match = _alias_line_pattern.match(line)
         if alias_line_match is not None:
-            flags.append(alias_line_match.group('flag'))
             continue
 
         value_line_match = _assign_value_line_pattern.match(line)
